@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-adblock-manager.c,v 1.3 2006/09/13 11:34:12 chpe Exp $
+ *  $Id: ephy-adblock-manager.c,v 1.4 2006/12/17 18:09:55 jframeau Exp $
  */
 
 #include "config.h"
@@ -36,6 +36,8 @@ G_DEFINE_TYPE (EphyAdBlockManager, ephy_adblock_manager, G_TYPE_OBJECT);
 #define EPHY_ADBLOCK_MANAGER_GET_PRIVATE(object) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
          EPHY_TYPE_ADBLOCK_MANAGER, EphyAdBlockManagerPrivate))
+
+
 /**
  * ephy_adblock_manager_set_blocker:
  * @shell: a #EphyAdBlockManager
@@ -95,6 +97,16 @@ ephy_adblock_manager_class_init (EphyAdBlockManagerClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
+	g_signal_new ("rules_changed",
+		      G_OBJECT_CLASS_TYPE (object_class),
+		      G_SIGNAL_RUN_FIRST,
+		      G_STRUCT_OFFSET (EphyAdBlockManagerClass, rules_changed),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__VOID,
+		      G_TYPE_NONE,
+		      0,
+		      0);
+
 	g_type_class_add_private (object_class, sizeof (EphyAdBlockManagerPrivate));
 }
 
