@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-find.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-embed-find.c,v 1.7 2006/12/01 21:29:19 chpe Exp $
  */
 
 #include "config.h"
@@ -67,15 +67,17 @@ ephy_embed_find_find (EphyEmbedFind *find,
  * ephy_embed_find_find_again:
  * @embed: an #EphyEmbedFind
  * @forward %TRUE to search forwards in the document
+ * @links_only: whether to only search the text in links
  *
  * Return value: whether a match was found
  **/
 EphyEmbedFindResult
 ephy_embed_find_find_again (EphyEmbedFind *find,
-			    gboolean forward)
+			    gboolean forward,
+			    gboolean links_only)
 {
 	EphyEmbedFindIface *iface = EPHY_EMBED_FIND_GET_IFACE (find);
-	return iface->find_again (find, forward);
+	return iface->find_again (find, forward, links_only);
 }
 
 void
