@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-find.h,v 1.5 2006/09/13 11:34:13 chpe Exp $
+ *  $Id: ephy-embed-find.h,v 1.6 2006/12/01 21:29:19 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_FIND_H
@@ -61,7 +61,8 @@ struct _EphyEmbedFindIface
 						 const char *search_string,
 						 gboolean links_only);
 	EphyEmbedFindResult (* find_again)	(EphyEmbedFind *find,
-						 gboolean forward);
+						 gboolean forward,
+						 gboolean links_only);
 	void	 (* set_selection)	(EphyEmbedFind *find,
 					 gboolean attention);
 	gboolean (* activate_link)	(EphyEmbedFind *find,
@@ -82,7 +83,8 @@ EphyEmbedFindResult	ephy_embed_find_find		(EphyEmbedFind *find,
 							 gboolean links_only);
 
 EphyEmbedFindResult	ephy_embed_find_find_again	(EphyEmbedFind *find,
-							 gboolean forward);
+							 gboolean forward,
+							 gboolean links_only);
 
 void	 ephy_embed_find_set_selection		(EphyEmbedFind *find,
 						 gboolean attention);
