@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.h,v 1.6.2.1 2006/09/13 11:48:35 chpe Exp $
+ *  $Id: EphyFind.h,v 1.8 2006/12/01 21:29:19 chpe Exp $
  */
 
 #ifndef TYPEAHEADFIND_H
@@ -44,7 +44,8 @@ class EphyFind
     void SetSelectionAttention (PRBool aAttention);
     EphyEmbedFindResult Find (const char *aSearchString,
 			      PRBool aLinksOnly);
-    EphyEmbedFindResult FindAgain (PRBool aForward);
+    EphyEmbedFindResult FindAgain (PRBool aForward,
+				   PRBool aLinksOnly);
     PRBool ActivateLink (GdkModifierType aMask);
 
   private:
