@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.31 2006/09/13 11:34:14 chpe Exp $
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.32 2006/12/15 14:01:55 chpe Exp $
  */
 
 /*
@@ -47,6 +47,7 @@
 
 #include "ephy-debug.h"
 #include "ephy-gui.h"
+#include "ephy-stock-icons.h"
 
 #include "AutoJSContextStack.h"
 #include "AutoWindowModalState.h"
@@ -160,7 +161,7 @@ GtkNSSKeyPairDialogs::DisplayGeneratingKeypairInfo (nsIInterfaceRequestor *ctx,
 					     GTK_WINDOW (dialog));
 	}
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
