@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,13 +15,13 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: mozilla-embed-single.h,v 1.9 2006/09/13 11:34:15 chpe Exp $
  */
 
 #ifndef MOZILLA_EMBED_SINGLE_H
 #define MOZILLA_EMBED_SINGLE_H
 
-#include "glib.h"
-#include "ephy-embed-shell.h"
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -32,25 +33,24 @@ G_BEGIN_DECLS
 #define MOZILLA_IS_EMBED_SINGLE_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), MOZILLA_TYPE_EMBED_SINGLE))
 #define MOZILLA_EMBED_SINGLE_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), MOZILLA_TYPE_EMBED_SINGLE, MozillaEmbedSingleClass))
 
-typedef struct MozillaEmbedSingle MozillaEmbedSingle;
-typedef struct MozillaEmbedSinglePrivate MozillaEmbedSinglePrivate;
+typedef struct MozillaEmbedSingle		MozillaEmbedSingle;
+typedef struct MozillaEmbedSingleClass		MozillaEmbedSingleClass;
+typedef struct MozillaEmbedSinglePrivate	MozillaEmbedSinglePrivate;
 
 struct MozillaEmbedSingle
 {
-	EphyEmbedSingle parent;
-        MozillaEmbedSinglePrivate *priv;
+	GObject parent;
+
+	/*< private >*/
+	MozillaEmbedSinglePrivate *priv;
 };
 
 struct MozillaEmbedSingleClass
 {
-        EphyEmbedSingleClass parent_class;
+	GObjectClass parent_class;
 };
 
-GType             mozilla_embed_single_get_type	     (void);
-
-EphyEmbedSingle  *mozilla_embed_single_new	     (void);
-
-gboolean	  mozilla_embed_single_init_services (MozillaEmbedSingle *single);
+GType	mozilla_embed_single_get_type	(void);
 
 G_END_DECLS
 
