@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.18 2004/12/18 21:51:47 chpe Exp $
+ *  $Id: ephy-file-chooser.c,v 1.25 2006/12/15 14:01:55 chpe Exp $
  */
 
 #include "config.h"
@@ -27,6 +27,7 @@
 #include "ephy-state.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
+#include "ephy-stock-icons.h"
 
 #include <gtk/gtkstock.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -34,7 +35,7 @@
 
 #define EPHY_FILE_CHOOSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_FILE_CHOOSER, EphyFileChooserPrivate))
 
-struct EphyFileChooserPrivate
+struct _EphyFileChooserPrivate
 {
 	char *persist_key;
 };
@@ -57,7 +58,7 @@ ephy_file_chooser_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyFileChooserClass),
 			NULL,
@@ -111,12 +112,12 @@ ephy_file_chooser_constructor (GType type,
 	object = parent_class->constructor (type, n_construct_properties,
 					    construct_params);
 
-	downloads_dir = ephy_file_downloads_dir ();
+	downloads_dir = ephy_file_get_downloads_dir ();
 	gtk_file_chooser_add_shortcut_folder
 		(GTK_FILE_CHOOSER (object), downloads_dir, NULL);
 	g_free (downloads_dir);
 
-	gtk_window_set_icon_name (GTK_WINDOW (object), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (object), EPHY_STOCK_EPHY);
 
 	return object;
 }
@@ -128,7 +129,7 @@ ephy_file_chooser_finalize (GObject *object)
 
 	g_free (dialog->priv->persist_key);
 
-	LOG ("EphyFileChooser finalised")
+	LOG ("EphyFileChooser finalised");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -282,7 +283,7 @@ ephy_file_chooser_class_init (EphyFileChooserClass *klass)
 							      "Persist Key",
 							      "The gconf key to which to persist the selected directory",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_type_class_add_private (object_class, sizeof (EphyFileChooserPrivate));
 }
