@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-stock-icons.c,v 1.26 2006/12/08 18:09:38 chpe Exp $
  */
 
 #include "config.h"
@@ -65,14 +65,8 @@ ephy_stock_icons_init (void)
 
 	for (i = 0; i < (int) G_N_ELEMENTS (items); i++)
 	{
-		char *fn;
-
 		icon_source = gtk_icon_source_new ();
-
-		fn = g_strconcat (items[i].stock_id, ".png", NULL);
 		gtk_icon_source_set_icon_name (icon_source, items[i].stock_id);
-		gtk_icon_source_set_filename (icon_source, ephy_file (fn));
-		g_free (fn);
 
 		icon_set = gtk_icon_set_new ();
 		gtk_icon_set_add_source (icon_set, icon_source);
@@ -99,4 +93,11 @@ ephy_stock_icons_init (void)
 
 	gtk_icon_factory_add_default (factory);
 	g_object_unref (factory);
+
+	/* GtkIconTheme will then look in Ephy custom hicolor dir
+	 * for icons as well as the standard search paths
+	 */
+	/* FIXME: multi-head! */
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+					   SHARE_DIR G_DIR_SEPARATOR_S "icons");
 }
