@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.c,v 1.82 2006/09/13 21:11:34 jframeau Exp $
+ *  $Id: ephy-location-entry.c,v 1.85 2006/12/18 12:35:02 chpe Exp $
  */
 
 #include "config.h"
@@ -40,6 +40,7 @@
 #include <gtk/gtkentry.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkcellrendererpixbuf.h>
 #include <gtk/gtkcelllayout.h>
 #include <gtk/gtktreemodelsort.h>
 #include <gtk/gtkstock.h>
@@ -75,6 +76,8 @@ struct _EphyLocationEntryPrivate
 	guint action_col;
 	guint keywords_col;
 	guint relevance_col;
+	guint extra_col;
+	guint favicon_col;
 
 	guint hash;
 
@@ -107,6 +110,7 @@ static const GtkTargetEntry url_drag_types [] =
 };
 
 static const GdkColor fallback_bg_colour = { 0, 0xf7f7, 0xf7f7, 0xbebe }; /* yellow-ish */
+static const GdkColor fallback_fg_colour = { 0, 0, 0, 0 }; /* black */
 
 static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
@@ -208,8 +212,7 @@ ephy_location_entry_style_set (GtkWidget *widget,
 	}
 	else
 	{
-		/* FIXME: fall back to black text maybe? */
-		priv->secure_fg_colour = widget->style->text[GTK_STATE_NORMAL];
+		priv->secure_fg_colour = fallback_fg_colour;
 	}
 
 	if (bg_colour != NULL)
@@ -997,17 +1000,21 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 				    guint text_col,
 				    guint action_col,
 				    guint keywords_col,
-				    guint relevance_col)
+				    guint relevance_col,
+				    guint extra_col,
+				    guint favicon_col)
 {
 	EphyLocationEntryPrivate *priv = le->priv;
 	GtkTreeModel *sort_model;
 	GtkEntryCompletion *completion;
-	GtkCellRenderer *cell;
+	GtkCellRenderer *cell, *extracell, *iconcell;
 
 	le->priv->text_col = text_col;
 	le->priv->action_col = action_col;
 	le->priv->keywords_col = keywords_col;
 	le->priv->relevance_col = relevance_col;
+	le->priv->extra_col = extra_col;
+	le->priv->favicon_col = favicon_col;
 
 	sort_model = gtk_tree_model_sort_new_with_model (model);
 	g_object_unref (model);
@@ -1024,12 +1031,37 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 	g_signal_connect_after (completion, "action-activated",
 				G_CALLBACK (action_activated_after_cb), le);
 
+	iconcell = gtk_cell_renderer_pixbuf_new ();
+
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
+				    iconcell, FALSE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
+				       iconcell, "pixbuf", favicon_col);
+
 	cell = gtk_cell_renderer_text_new ();
+	g_object_set (cell, 
+			"ellipsize", PANGO_ELLIPSIZE_END,
+			"ellipsize-set", TRUE,
+			NULL);
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
 				    cell, TRUE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
 				       cell, "text", text_col);
 
+	extracell = gtk_cell_renderer_text_new ();
+	g_object_set (extracell, 
+			"ellipsize", PANGO_ELLIPSIZE_END,
+			"ellipsize-set", TRUE,
+			"foreground", "Gray",
+			"foreground-set", TRUE,
+			"alignment", PANGO_ALIGN_RIGHT,
+			NULL);
+
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion),
+				    extracell, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
+				       extracell, "text", extra_col);
+
 	gtk_entry_set_completion (GTK_ENTRY (priv->icon_entry->entry), completion);
 	g_object_unref (completion);
 }
