@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-entry.h,v 1.22 2006/09/13 11:34:20 chpe Exp $
+ *  $Id: ephy-location-entry.h,v 1.24 2006/12/18 12:35:02 chpe Exp $
  */
 
 #ifndef EPHY_LOCATION_ENTRY_H
@@ -71,7 +71,9 @@ void		ephy_location_entry_set_completion	(EphyLocationEntry *le,
 							 guint text_col,
 							 guint action_col,
 							 guint keywords_col,
-							 guint relevance_col);
+							 guint relevance_col,
+							 guint extra_col,
+							 guint favicon_col);
 
 void		ephy_location_entry_set_location	(EphyLocationEntry *le,
 							 const char *address,
