@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.81 2006/02/10 22:49:29 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.84 2006/12/17 19:19:09 chpe Exp $
  */
 
 #include "config.h"
@@ -296,6 +296,13 @@ button_deactivate_cb (GtkMenuShell *ms,
 {
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 	gtk_button_released (GTK_BUTTON (button));
+
+	/*
+		Currently, GObject leaks connection IDs created with
+		g_signal_connect_object ()
+		See glib bug #118536
+	*/
+	g_signal_handlers_disconnect_by_func(ms, button_deactivate_cb, button);
 }
 
 static void
@@ -562,7 +569,7 @@ ephy_topic_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyTopicActionClass),
 			(GBaseInitFunc) NULL,
