@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.h,v 1.6 2006/09/13 11:34:22 chpe Exp $
+ *  $Id: ephy-completion-model.h,v 1.8 2006/12/18 12:35:02 chpe Exp $
  */
 
 #ifndef EPHY_COMPLETION_MODEL_H
@@ -40,6 +40,8 @@ typedef enum
 	EPHY_COMPLETION_ACTION_COL,
 	EPHY_COMPLETION_KEYWORDS_COL,
 	EPHY_COMPLETION_RELEVANCE_COL,
+	EPHY_COMPLETION_EXTRA_COL,
+	EPHY_COMPLETION_FAVICON_COL,
 	N_COL
 } EphyCompletionColumn;
 
