@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.109 2006/10/02 20:32:47 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.111 2006/12/17 19:16:03 chpe Exp $
  */
 
 #include "config.h"
@@ -272,7 +272,7 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Clear History"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (confirmation_dialog_response_cb),
@@ -475,6 +475,8 @@ cmd_delete (GtkAction *action,
 		{
 			ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->sites_view));
 		}
+		
+		g_list_free (selected);
 	}
 }
 
