@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-link.c,v 1.7.4.3 2006/09/13 21:46:46 chpe Exp $
+ *  $Id: ephy-link.c,v 1.12 2006/12/05 13:43:05 wbolster Exp $
  */
 
 #include "config.h"
@@ -114,7 +114,7 @@ ephy_link_flags_from_current_event (void)
 		{
 			flags = EPHY_LINK_NEW_WINDOW;
 		}
-		else if (state == 0)
+		else if (state == 0 || state == GDK_CONTROL_MASK)
 		{
 			flags = EPHY_LINK_NEW_TAB;
 		}
