@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-main.c,v 1.68 2006/09/13 11:34:22 chpe Exp $
+ *  $Id: ephy-main.c,v 1.71 2006/12/15 14:01:57 chpe Exp $
  */
 
 #include "config.h"
@@ -611,7 +611,7 @@ main (int argc,
 	g_set_application_name (_("Web Browser"));
 
 	/* Set default window icon */
-	gtk_window_set_default_icon_name ("web-browser");
+	gtk_window_set_default_icon_name (EPHY_STOCK_EPHY);
 
 	startup_error_quark = g_quark_from_static_string ("epiphany-startup-error");
 
