@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005, 2006 Christian Persch
+ *  Copyright © 2002 Jorn Baayen
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.56 2006/06/16 14:11:22 wbolster Exp $
+ *  $Id: ephy-session.c,v 1.59 2006/12/15 14:01:57 chpe Exp $
  */
 
 #include "config.h"
@@ -34,6 +34,7 @@
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
 #include "ephy-debug.h"
+#include "ephy-stock-icons.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtkmain.h>
@@ -104,7 +105,7 @@ ephy_session_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphySessionClass),
 			NULL, /* base_init */
@@ -117,7 +118,7 @@ ephy_session_get_type (void)
 			(GInstanceInitFunc) ephy_session_init
 		};
 
-		static const GInterfaceInfo extension_info =
+		const GInterfaceInfo extension_info =
 		{
 			(GInterfaceInitFunc) ephy_session_iface_init,
 			NULL,
@@ -282,7 +283,7 @@ confirm_shutdown_cb (GnomeClient *client,
 			       _("_Abort Downloads"), GTK_RESPONSE_ACCEPT);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
 
@@ -617,7 +618,7 @@ session_command_autoresume (EphySession *session,
 			       _("_Recover"), GTK_RESPONSE_ACCEPT);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Crash Recovery"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
