@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.144.2.2 2006/09/13 11:48:52 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.149 2006/12/15 14:01:57 chpe Exp $
  */
 
 #include "config.h"
@@ -52,6 +52,7 @@
 #include "ephy-toolbar.h"
 #include "ephy-prefs.h"
 #include "ephy-gui.h"
+#include "ephy-stock-icons.h"
 
 #ifdef ENABLE_NETWORK_MANAGER
 #include "ephy-net-monitor.h"
@@ -199,7 +200,7 @@ ephy_shell_add_sidebar_cb (EphyEmbedSingle *embed_single,
 					 _("Sidebar extension required"));
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Sidebar Extension Required"));
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 		  _("The link you clicked needs the sidebar extension to be "
@@ -508,6 +509,15 @@ ephy_shell_new_tab_full (EphyShell *shell,
 
 	ephy_window_add_tab (window, tab, position, jump_to);
 
+	if (previous_embed != NULL)
+	{
+		ephy_embed_shistory_copy (previous_embed,
+					  embed,
+					  TRUE,   /* back history */
+					  TRUE,   /* forward history */
+					  FALSE); /* current index */
+	}
+
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
 	if ((flags & EPHY_NEW_TAB_DONT_SHOW_WINDOW) == 0)
@@ -530,8 +540,24 @@ ephy_shell_new_tab_full (EphyShell *shell,
 	}
 	else if (flags & EPHY_NEW_TAB_OPEN_PAGE)
 	{
+		EphyEmbedLoadFlags load_flags = 0;
+
 		g_assert (url != NULL);
-		ephy_embed_load_url (embed, url);
+
+		if (flags & EPHY_NEW_TAB_ALLOW_FIXUP)
+		{
+			load_flags = EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP;
+		}
+		else
+		{
+			load_flags = EPHY_EMBED_LOAD_FLAGS_NONE;
+		}
+		/* FIXME */
+		/* We need to audit every caller to see if this 
+		   won't make us send referer for undesirable loads.
+	           Passing NULL referrer atm  */
+		ephy_embed_load (embed, url, load_flags, NULL);
+
 		is_empty = url_is_empty (url);
 	}
 
@@ -556,15 +582,6 @@ ephy_shell_new_tab_full (EphyShell *shell,
                 }
         }
 
-	if (previous_embed != NULL)
-	{
-		ephy_embed_shistory_copy (previous_embed,
-					  embed,
-					  TRUE,   /* back history */
-					  FALSE,  /* forward history */
-					  FALSE); /* current index */
-	}
-
 	return tab;
 }
 
